<?php
/** Interlingue (Interlingue)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jmb
 * @author Malafaya
 * @author Reedy
 * @author Remember the dot
 * @author Renan
 * @author Valodnieks
 * @author לערי ריינהארט
 */

$messages = array(
'underline-always'  => 'Sempre',
'underline-never'   => 'Nequande',
'underline-default' => 'Criterie de navigator',

# Dates
'sunday'        => 'soledí',
'monday'        => 'lunedí',
'tuesday'       => 'mardí',
'wednesday'     => 'mercurdí',
'thursday'      => 'jovedí',
'friday'        => 'venerdí',
'saturday'      => 'saturdí',
'sun'           => 'sol',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mer',
'thu'           => 'jov',
'fri'           => 'ven',
'sat'           => 'sat',
'january'       => 'januar',
'february'      => 'februar',
'march'         => 'marte',
'april'         => 'april',
'may_long'      => 'may',
'june'          => 'junio',
'july'          => 'julí',
'august'        => 'august',
'september'     => 'septembre',
'october'       => 'octobre',
'november'      => 'novembre',
'december'      => 'decembre',
'january-gen'   => 'januar',
'february-gen'  => 'februar',
'march-gen'     => 'marte',
'april-gen'     => 'april',
'may-gen'       => 'may',
'june-gen'      => 'junio',
'july-gen'      => 'juli',
'august-gen'    => 'august',
'september-gen' => 'septembre',
'october-gen'   => 'octobre',
'november-gen'  => 'novembre',
'december-gen'  => 'decembre',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'may',
'jun'           => 'jun',
'jul'           => 'jul',
'aug'           => 'aug',
'sep'           => 'sep',
'oct'           => 'oct',
'nov'           => 'nov',
'dec'           => 'dec',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Categorie|Categories}}',
'category_header'        => 'Articules in categorie "$1"',
'category-media-header'  => 'Multimedia in categorie "$1"',
'listingcontinuesabbrev' => 'cont.',

'mainpagetext' => "'''Software del wiki installat con successe.'''",

'about'         => 'Concernent',
'article'       => 'Articul',
'newwindow'     => '(inaugurar in nov planca de fenestre)',
'cancel'        => 'Anullar',
'moredotdotdot' => 'Plu...',
'mypage'        => 'Mi págine',
'mytalk'        => 'Mi discussion',
'anontalk'      => 'Discussion por ti ci IP',
'and'           => '&#32;e',

# Cologne Blue skin
'qbfind'         => 'Constatar',
'qbedit'         => 'Redacter',
'qbpageoptions'  => 'Págine de optiones',
'qbpageinfo'     => 'Págine de information',
'qbmyoptions'    => 'Mi optiones',
'qbspecialpages' => 'Págines special',

'errorpagetitle'    => 'Errore',
'returnto'          => 'Retornar a $1.',
'tagline'           => 'De {{SITENAME}}',
'help'              => 'Auxilie',
'search'            => 'Serchar',
'searchbutton'      => 'Serchar',
'go'                => 'Ear',
'searcharticle'     => 'Ear',
'history'           => 'Historie',
'history_short'     => 'Historie',
'updatedmarker'     => 'modernisat desde mi ultim visitation',
'printableversion'  => 'Version por impression',
'permalink'         => 'Catenun permanent',
'edit'              => 'Redacter',
'editthispage'      => 'Redacter',
'delete'            => 'Deleter',
'deletethispage'    => 'Deleter ti págine',
'undelete_short'    => 'Restaurar {{PLURAL:$1|1 modification|$1 modificationes}}',
'protect'           => 'Gardar',
'protectthispage'   => 'Gardar ti págine',
'unprotect'         => 'Desgardar',
'unprotectthispage' => 'Desgardar ti págine',
'newpage'           => 'Nov págine',
'talkpage'          => 'Parlar in ti págine',
'talkpagelinktext'  => 'Discussion',
'specialpage'       => 'Págine special',
'personaltools'     => 'Utensiles personal',
'postcomment'       => 'Impostar un comenta',
'articlepage'       => 'Vider li articul',
'talk'              => 'Discussion',
'views'             => 'Vistas',
'toolbox'           => 'Buxe de utensiles',
'userpage'          => 'Vider págine del usator',
'imagepage'         => 'Vider págine del image',
'viewtalkpage'      => 'Vider li discussion',
'otherlanguages'    => 'Altri lingues',
'redirectedfrom'    => '(Redirectet de $1)',
'redirectpagesub'   => 'Págine de redirecterion',
'viewcount'         => 'Ti págine ha esset consultat {{PLURAL:$1|un vez|$1 vezes}}.',
'protectedpage'     => 'Un protectet págine',
'jumpto'            => 'Saltar a:',
'jumptonavigation'  => 'navigation',
'jumptosearch'      => 'serchar',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Concernent {{SITENAME}}',
'aboutpage'            => 'Project:Concernent',
'copyright'            => 'Contenete disponibil sub $1.',
'copyrightpage'        => '{{ns:project}}:Jure editorial',
'currentevents'        => 'Eventus current',
'currentevents-url'    => 'Project:Eventus current',
'disclaimers'          => 'Advertimentes',
'disclaimerpage'       => 'Project:Advertimentes comun',
'edithelp'             => 'Redacter auxilie',
'edithelppage'         => 'Redactent págine de auxilie',
'helppage'             => 'Auxilie:Contenete',
'mainpage'             => 'Págine principal',
'mainpage-description' => 'Págine principal',
'portal'               => 'Págine de comunité',
'portal-url'           => 'Project:Págine de comunité',
'privacy'              => 'Politica de privatie',
'privacypage'          => 'Project:Politica de privatie',

'retrievedfrom'           => 'Recuperat de "$1"',
'youhavenewmessages'      => 'Vu have $1 ($2).',
'newmessageslink'         => 'nov missages',
'newmessagesdifflink'     => 'vider missages antiqui',
'youhavenewmessagesmulti' => 'Vu have nov missages in $1',
'editsection'             => 'redacter',
'editold'                 => 'redacter',
'editsectionhint'         => 'Redacter division: $1',
'toc'                     => 'Contenetes',
'showtoc'                 => 'monstrar',
'hidetoc'                 => 'ocultar',
'viewdeleted'             => 'Vider $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Articul',
'nstab-user'      => 'Págine de usator',
'nstab-special'   => 'Págine special',
'nstab-project'   => 'Págine de projecte',
'nstab-image'     => 'Figura',
'nstab-mediawiki' => 'Missage',
'nstab-template'  => 'Avise',
'nstab-help'      => 'Auxilie',
'nstab-category'  => 'Categorie',

# General errors
'error'                => 'Erra',
'unexpected'           => 'Valor ínexpectat: "$1"="$2".',
'wrong_wfQuery_params' => 'Normes íncorect por wfQuery()<br />
Function: $1<br />
Question: $2',
'viewsource'           => 'Vider contenete',
'viewsourcefor'        => 'por $1',

# Login and logout pages
'logouttext'                 => "'''Vu ha terminat vor session.'''

Vu posse continuar usar {{SITENAME}} anonimimen, o vu posse aperter un session denov quam li sam usator o quam un diferent usator.",
'welcomecreation'            => '== Benevenit, $1! == 
Tui conto hat esset creat. 
Ne oblivia de mutar tui [[Special:Preferences|preferenties de {{SITENAME}}]].',
'yourname'                   => 'Nómine de usator:',
'yourpassword'               => 'Parol-clave:',
'yourpasswordagain'          => 'Parol-clave denov:',
'remembermypassword'         => 'Memorar mi passa-parol (per cookie)',
'yourdomainname'             => 'Tui dominia:',
'login'                      => 'Aperter session',
'nav-login-createaccount'    => 'Crear un conto o intrar',
'loginprompt'                => 'Cookies deve esser permisset por intrar in {{SITENAME}}.',
'userlogin'                  => 'Crear un conto o intrar',
'logout'                     => 'Surtida',
'userlogout'                 => 'Surtida',
'notloggedin'                => 'Vu ne ha intrat',
'nologinlink'                => 'Crear un conto',
'createaccount'              => 'Crear un conto',
'gotaccount'                 => 'Ja have un conto? $1.',
'gotaccountlink'             => 'Intrar',
'badretype'                  => 'Li passa-paroles queles vu tippat ne es identic.',
'loginerror'                 => 'Erra in initiation del session',
'nocookieslogin'             => '{{SITENAME}} utilisa cookies por far intrar usatores. Vu nu ne permisse cookies. Ples permisser les e provar denov.',
'loginsuccesstitle'          => 'Apertion de session successosi',
'loginsuccess'               => 'Vu ha apertet vor session in {{SITENAME}} quam "$1".',
'wrongpassword'              => 'Parol-clave íncorect inscrit.
Pleser prova denov.',
'wrongpasswordempty'         => 'Parol-clave inscrit esset nud.
Pleser prova denov.',
'mailmypassword'             => 'Invia me un nov passa-parol per electronic post',
'acct_creation_throttle_hit' => 'Vu ja ha creat $1 contos. Vu ne posse crear pli mult quam to.',
'loginlanguagelabel'         => 'Lingue: $1',

# Password reset dialog
'oldpassword' => 'Anteyan passa-parol:',
'newpassword' => 'Nov passa-parol:',
'retypenew'   => 'Confirmar nov passa-parol',

# Edit page toolbar
'bold_tip'     => 'Textu in nigri',
'italic_tip'   => 'Textu cursivmen',
'link_tip'     => 'Catenun intern',
'extlink_tip'  => 'Catenun extern (memorar prefixe http://)',
'headline_tip' => 'Division de nivelle 2',
'math_tip'     => 'Formul mathematical (LaTeX)',
'nowiki_tip'   => 'Ignorar formate wiki',
'image_tip'    => 'File fixat',
'media_tip'    => 'Catenun in file de multimedia',
'sig_tip'      => 'Tui signature che hor e date',
'hr_tip'       => 'Linea horizontal (use sin excess)',

# Edit pages
'summary'                => 'Summarium:',
'subject'                => 'Tema/Division:',
'minoredit'              => 'Ti es un redaction minori',
'watchthis'              => 'Vigilar ti págine',
'savearticle'            => 'Conservar págine',
'preview'                => 'Prevision',
'showpreview'            => 'Monstrar prevision',
'showdiff'               => 'Monstrar changes',
'whitelistedittitle'     => 'Exige que vu es identificat por redacter',
'whitelistedittext'      => 'Vu have que $1 por redacter págines.',
'loginreqtitle'          => 'Apertion de session obligatori',
'accmailtitle'           => 'Li passa-parol es inviat.',
'accmailtext'            => "Li passa-parol por '$1' ha esset inviat a $2.",
'newarticle'             => '(Nov)',
'updated'                => '(Modernisat)',
'previewnote'            => "'''Memora se que ti es solmen un prevision.'''
Tui changes ancor ne ha esset conservat!",
'editing'                => 'Redactent $1',
'editingsection'         => 'Redactent $1 (division)',
'editingcomment'         => 'Redactent $1 (nov division)',
'yourtext'               => 'Tui textu',
'yourdiff'               => 'Diferenties',
'copyrightwarning'       => "Omni contributiones a {{SITENAME}} es considerat quam publicat sub li termines del $2 (ples vider $1 por plu mult detallies). Si vu ne vole que vor ovres mey esser modificat e distribuet secun arbitrie, ples ne inviar les. Adplu, ples contribuer solmen vor propri ovres o ovres ex un fonte quel es líber de jures. '''NE UTILISA OVRES SUB JURE EDITORIAL SIN DEFINITIV AUTORISATION!'''",
'template-protected'     => '(gardat)',
'template-semiprotected' => '(medie-gardat)',

# "Undo" feature
'undo-success' => 'Li redaction posse es desfat. Pleser controla li comparation sub verificar que ti es quo vu cari acter, e tande conservar li changes infra por terminar e desfar li redaction.',
'undo-failure' => 'Li redaction ne posse esser desfat payand conflicte de redactiones.',
'undo-norev'   => 'Li redaction ne posse esser defat pro que it ne existe o esset deletet.',
'undo-summary' => 'Desfat revision $1 per [[Special:Contributions/$2|$2]] ([[User talk:$2|discussion]])',

# History pages
'currentrev'          => 'Ultim revision',
'revisionasof'        => 'Revision de $1',
'revision-info'       => 'Revision de $1 e il ha fabricat de $2',
'previousrevision'    => '← Revision antiqui',
'nextrevision'        => 'Revision sequent →',
'currentrevisionlink' => 'Ultim revision',
'cur'                 => 'hod',
'next'                => 'prox',
'page_first'          => 'prim',
'page_last'           => 'ultim',
'histfirst'           => 'Plu antiqui',
'histlast'            => 'Plu recent',

# Revision feed
'history-feed-item-nocomment' => '$1 in $2',

# Diffs
'history-title' => 'Revision del historie de "$1"',
'lineno'        => 'Linea $1:',
'editundo'      => 'anullar',

# Search results
'toomanymatches' => 'Anc mult concurses esset retornat, pleser prova un question diferent',
'prevn'          => '{{PLURAL:$1|$1}} anteriori',
'nextn'          => 'proxim {{PLURAL:$1|$1}}',
'viewprevnext'   => 'Vider ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url' => 'Help:Contenete',
'powersearch'    => 'Serchar avansat',

# Quickbar
'qbsettings' => 'Personalisation del barre de utensiles',

# Preferences page
'preferences'       => 'Preferenties',
'mypreferences'     => 'Mi preferenties',
'prefsnologin'      => 'Vu ne ha intrat',
'changepassword'    => 'Modificar passa-parol',
'skin-preview'      => 'Prevision',
'saveprefs'         => 'Conservar',
'searchresultshead' => 'Serchar',
'youremail'         => 'E-mail:',
'uid'               => 'Identification de usator:',
'yourrealname'      => 'Nómine real:',
'yourlanguage'      => 'Lingue:',
'yourvariant'       => 'Variante:',
'yournick'          => 'Nov signature:',
'yourgender'        => 'Génere:',

# Groups
'group-user'  => 'Usatores',
'group-sysop' => 'Administratores',

'group-user-member' => 'Usator',

'grouppage-user'       => '{{ns:project}}:Usatores',
'grouppage-sysop'      => '{{ns:project}}:Administratores',
'grouppage-bureaucrat' => '{{ns:project}}:Burócrates',
'grouppage-suppress'   => '{{ns:project}}:Vigilatores',

# User rights log
'rightslog'  => 'Diarium de jures de usator',
'rightsnone' => '(null)',

# Recent changes
'nchanges'          => '$1 {{PLURAL:$1|change|changes}}',
'recentchanges'     => 'Nov changes',
'recentchangestext' => 'Seque sur ti-ci págine li ultim modificationes al wiki.',
'rclistfrom'        => 'Monstrar li nov modificationes desde $1.',
'rcshowhideminor'   => '$ redactiones minori',
'rcshowhidebots'    => '$1 machines',
'rcshowhideliu'     => '$1 usatores registrat',
'rcshowhideanons'   => '$1 usatores anonim',
'rcshowhidemine'    => '$1 mi redactiones',
'rclinks'           => 'Monstrar li $1 ultim modificationes fat durante li $2 ultim dies<br />$3.',
'diff'              => 'dif',
'hist'              => 'hist',
'hide'              => 'Ocultar',
'show'              => 'Monstrar',
'minoreditletter'   => 'm',
'newpageletter'     => 'N',

# Recent changes linked
'recentchangeslinked'         => 'Changes referet',
'recentchangeslinked-feed'    => 'Relatet modificationes',
'recentchangeslinked-toolbox' => 'Changes referet',

# Upload
'upload'          => 'Cargar file',
'uploadbtn'       => 'Cargar file',
'uploadlogpage'   => 'Diarium de cargament',
'filedesc'        => 'Descrition',
'savefile'        => 'Conservar file',
'uploadedimage'   => 'cargat "[[$1]]"',
'watchthisupload' => 'Vigilar ti file',

# Special:ListFiles
'imgfile'   => 'archive',
'listfiles' => 'Archives',

# File description page
'file-anchor-link'    => 'Figura',
'filehist'            => 'Historic de figura',
'filehist-current'    => 'current',
'filehist-datetime'   => 'Date/Témpor',
'filehist-user'       => 'Usator',
'filehist-dimensions' => 'Dimensiones',
'filehist-filesize'   => 'Mesura de file',
'filehist-comment'    => 'Comentarie',
'imagelinks'          => 'Catenunes por ti file',

# File deletion
'filedelete-submit' => 'Deleter',

# MIME search
'mimesearch' => 'Serchar MIME',

# Unwatched pages
'unwatchedpages' => 'Págines desvigilat',

# List redirects
'listredirects' => 'Liste de redirecteriones',

# Unused templates
'unusedtemplates'     => 'Avises sin use',
'unusedtemplatestext' => 'Ti págine lista omni li págines in li spacie de nómine {{ns:template}} quel ne es includet in altri págine. Memorar de controlar por altri catenunes por li avises ante de deleter les.',
'unusedtemplateswlh'  => 'altri catenunes',

# Random page
'randompage' => 'Págine sporadic',

# Statistics
'statistics' => 'Statistica',

'brokenredirects-edit'   => 'redacter',
'brokenredirects-delete' => 'deleter',

'withoutinterwiki'         => 'Págines sin catenunes de lingue',
'withoutinterwiki-summary' => 'Li proxim págines ne liga por altri versiones de lingue.',
'withoutinterwiki-legend'  => 'Prefixe',
'withoutinterwiki-submit'  => 'Monstrar',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|categorie|categories}}',
'nmembers'                => '$1 {{PLURAL:$1|usator|usatores}}',
'lonelypages'             => 'Orfani págines',
'uncategorizedpages'      => 'Págines íncategorizet',
'uncategorizedcategories' => 'Categories íncategorizet',
'uncategorizedimages'     => 'Figuras íncategorizet',
'uncategorizedtemplates'  => 'Avises íncategorizet',
'unusedcategories'        => 'Categories sin use',
'unusedimages'            => 'Figuras sin use',
'wantedpages'             => 'Págines carit',
'shortpages'              => 'Págines curt',
'longpages'               => 'Págines long',
'deadendpages'            => 'Págines sin exeada',
'listusers'               => 'Liste de usatores',
'newpages'                => 'Nov págines',
'ancientpages'            => 'Li max old págines',
'move'                    => 'Mover',
'movethispage'            => 'Mover ti págine',
'unusedimagestext'        => 'Li proxim files existe ma ne esser fixat in alquel págine. Pleser note que altri págines de Internet posse ligar por un file che un URL direct, e talmen posse silentment esser listat ci malgré essant in usu activ.',
'unusedcategoriestext'    => 'Li proxim págines de categorie existe, benque ne existe altri págine o categorie que far usu de les.',

# Book sources
'booksources' => 'Librari fontes',

# Special:Log
'specialloguserlabel'  => 'Usator:',
'speciallogtitlelabel' => 'Titul:',
'log'                  => 'Diariumes',
'all-logs-page'        => 'Omni li diariumes public',

# Special:AllPages
'allpages'       => 'Omni li págines',
'alphaindexline' => '$1 til $2',
'nextpage'       => 'Proxim págine ($1)',
'prevpage'       => 'Ultim págine ($1)',
'allarticles'    => 'Omni li articules',
'allpagessubmit' => 'Ear',

# Special:Categories
'categories' => 'Categories',

# Special:LinkSearch
'linksearch'    => 'Catenunes extern',
'linksearch-ns' => 'Spacie de nómine:',

# E-mail user
'emailuser' => 'Parlar che ti usator',

# Watchlist
'watchlist'            => 'Liste de págines vigilat',
'mywatchlist'          => 'Mi liste de págines vigilat',
'addedwatch'           => 'Adjuntet al liste',
'addedwatchtext'       => "Li págine ''[[$1]]'' ha esset adjuntet a vor [[Special:Watchlist|liste de sequet págines]]. Li proxim modificationes de ti ci págine e del associat págine de discussion va esser listat ci, e li págine va aperir '''aspessat''' in li [[Special:RecentChanges|liste de recent modificationes]] por esser trovat plu facilmen. Por supresser ti ci págine ex vor liste, ples claccar sur « Ne plu sequer » in li cadre de navigation.",
'watch'                => 'Vigilar',
'watchthispage'        => 'Vigilar ti págine',
'unwatch'              => 'Desvigilar',
'watchlist-details'    => '{{PLURAL:$1|$1 págine|$1 págines}} in tui liste de págines vigilat, sin págines de discussion.',
'wlheader-enotif'      => '* Li notification de e-mail es permisset.',
'wlheader-showupdated' => "* Págines quel hat esset mutat desde tui ultim visitation es monstrat in '''nigri'''",
'wlnote'               => "Infra {{PLURAL:$1|es li ultim change|es li ultim '''$1''' changes}} in li ultim {{PLURAL:$2|hor|'''$2''' hores}}.",
'wlshowlast'           => 'Monstra ultim $1 hores $2 dies $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Vigilant...',
'unwatching' => 'Desvigilant...',

'created' => 'creat',

# Delete
'deletepage'            => 'Deleter págine',
'delete-legend'         => 'Deleter',
'actioncomplete'        => 'Processu complet',
'deletedarticle'        => 'deletet "[[$1]]"',
'dellogpage'            => 'Diarium de deletion',
'deletecomment'         => 'Motive:',
'deleteotherreason'     => 'Altri motive:',
'deletereasonotherlist' => 'Altri motive',

# Rollback
'rollbacklink' => 'desfar',

# Protect
'protectlogpage'      => 'Diarium de protection',
'prot_1movedto2'      => '[[$1]] hat movet por [[$2]]',
'protectcomment'      => 'Motive:',
'protect-level-sysop' => 'Administratores solmen',
'protect-expiring'    => 'expira $1 (UTC)',
'restriction-type'    => 'Permission:',

# Restrictions (nouns)
'restriction-edit' => 'Redacter',
'restriction-move' => 'Mover',

# Undelete
'undeletebtn'            => 'Restaurar',
'undelete-search-submit' => 'Serchar',

# Namespace form on various pages
'namespace'      => 'Spacie de nómine:',
'invert'         => 'Inverter selection',
'blanknamespace' => '(Principal)',

# Contributions
'contributions' => 'Contributiones de usator',
'mycontris'     => 'Mi contributiones',
'uctop'         => '(prim)',
'month'         => 'De mensu (e anterioris):',
'year'          => 'De annu (e anterioris):',

'sp-contributions-newbies-sub' => 'Por nov contos',
'sp-contributions-blocklog'    => 'diarium de bloc',
'sp-contributions-talk'        => 'Discussion',

# What links here
'whatlinkshere'            => 'Quo catenunes ci',
'whatlinkshere-title'      => 'Págines quo liga por "$1"',
'whatlinkshere-page'       => 'Págine:',
'isredirect'               => 'págine de redirecterion',
'istemplate'               => 'inclusion',
'whatlinkshere-prev'       => '{{PLURAL:$1|anterior|$1 anterioris}}',
'whatlinkshere-next'       => '{{PLURAL:$1|proxim|proxim $1}}',
'whatlinkshere-links'      => '← catenunes',
'whatlinkshere-hideredirs' => '$1 redirectiones',
'whatlinkshere-hidetrans'  => '$1 transclusiones',
'whatlinkshere-hidelinks'  => '$1 catenunes',
'whatlinkshere-hideimages' => '$1 catenunes de figura',
'whatlinkshere-filters'    => 'Filtres',

# Block/unblock
'blockip'            => 'Blocar usator',
'ipbreason'          => 'Motive:',
'ipbotheroption'     => 'altri',
'ipblocklist'        => 'Blocat adresses e usatores',
'ipblocklist-submit' => 'Serchar',
'infiniteblock'      => 'infinit',
'blocklink'          => 'blocar',
'unblocklink'        => 'desblocar',
'contribslink'       => 'contribs',
'blocklogpage'       => 'Diarium de bloc',
'blocklogentry'      => '"[[$1]]" hat blocat che un témpor de expiration de $2 $3',

# Move page
'movearticle' => 'Mover págine:',
'movenologin' => 'Vu ne ha intrat',
'newtitle'    => 'Por nov titul:',
'move-watch'  => 'Vigilar ti págine',
'movepagebtn' => 'Mover págine',
'movedto'     => 'movet por',
'1movedto2'   => '[[$1]] hat movet por [[$2]]',
'movelogpage' => 'Diarium de movementiones',
'movereason'  => 'Motive:',
'revertmove'  => 'reverter',

# Export
'export' => 'Exportar págines',

# Namespace 8 related
'allmessages' => 'Liste del missages del sistema',

# Thumbnails
'thumbnail-more' => 'Expander',

# Special:Import
'xml-error-string' => '$1 in linea $2, col $3 (byte $4): $5',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Tui págine de usator',
'tooltip-pt-anonuserpage'         => 'Li págine de usator por li adresse de IP vu es redactent quam',
'tooltip-pt-mytalk'               => 'Tui págine de discussion',
'tooltip-pt-anontalk'             => 'Discussion pri redactiones de adresses de IP',
'tooltip-pt-preferences'          => 'Tui preferenties',
'tooltip-pt-watchlist'            => 'Li liste de págines quo vu controla li changes',
'tooltip-pt-mycontris'            => 'Liste de tui contributiones',
'tooltip-pt-login'                => 'Vu es incorageat por crear un conto; támen, it ne esser mandatorio',
'tooltip-pt-anonlogin'            => 'Vu es incorageat por crear un conto; támen, it ne esser mandatorio',
'tooltip-pt-logout'               => 'Surtida',
'tooltip-ca-talk'                 => 'Discussion pri li contenete de págine',
'tooltip-ca-edit'                 => 'Vu posse redacter ti págine. Pleser usar li buton "Monstrar prevision" ante de conservar',
'tooltip-ca-addsection'           => 'Comensar un nov division',
'tooltip-ca-viewsource'           => 'Ti págine es gardat. Vu posse vider li contenete',
'tooltip-ca-history'              => 'Revisiones passat de ti págine',
'tooltip-ca-protect'              => 'Gardar ti págine',
'tooltip-ca-unprotect'            => 'Desgardar ti págine',
'tooltip-ca-delete'               => 'Deleter ti págine',
'tooltip-ca-undelete'             => 'Restaurar li redactiones executet pro ti págine ante de it esser deletet',
'tooltip-ca-move'                 => 'Mover ti págine',
'tooltip-ca-watch'                => 'Adjunter ti págine pro tui liste de págines vigilat',
'tooltip-ca-unwatch'              => 'Desvigilar ti págine de tui liste de págines vigilat',
'tooltip-search'                  => 'Serchar {{SITENAME}}',
'tooltip-search-go'               => 'Ear por un págine che ti nómine exact, si it exister',
'tooltip-search-fulltext'         => 'Serchar págines che ti textu',
'tooltip-p-logo'                  => 'Visita li págine principal',
'tooltip-n-mainpage'              => 'Visita li págine principal',
'tooltip-n-portal'                => 'Pri li projecte, quo vu posse executer, u constatar coses',
'tooltip-n-currentevents'         => 'Constata funde de information sur eventus current',
'tooltip-n-recentchanges'         => 'Li liste de nov changes vice wiki',
'tooltip-n-randompage'            => 'Cargar un págine sporadic',
'tooltip-n-help'                  => 'Li loco por constatar auxilie',
'tooltip-t-whatlinkshere'         => 'Liste de omni págines que liga quel por ci',
'tooltip-t-recentchangeslinked'   => 'Nov changes in págines ligat in ti págine',
'tooltip-feed-rss'                => 'Feed RSS por ti págine',
'tooltip-feed-atom'               => 'Feed atom por ti págine',
'tooltip-t-contributions'         => 'Vider li liste de contributiones de ti usator',
'tooltip-t-emailuser'             => 'Inviar un e-mail por ti usator',
'tooltip-t-upload'                => 'Cargar files',
'tooltip-t-specialpages'          => 'Liste de omni págines special',
'tooltip-t-print'                 => 'Version por impression de ti págine',
'tooltip-t-permalink'             => 'Catenun permanent por ti revision de págine',
'tooltip-ca-nstab-main'           => 'Vider li págine de contenete',
'tooltip-ca-nstab-user'           => 'Vider li págine de usator',
'tooltip-ca-nstab-media'          => 'Vider li págine de media',
'tooltip-ca-nstab-special'        => 'Ti es un págine special, vu ne posse redacter it',
'tooltip-ca-nstab-project'        => 'Vider li págine de projecte',
'tooltip-ca-nstab-image'          => 'Vider li págine de figura',
'tooltip-ca-nstab-mediawiki'      => 'Vider li missage de sistema',
'tooltip-ca-nstab-template'       => 'Vider li avise',
'tooltip-ca-nstab-help'           => 'Vider li págine de auxilie',
'tooltip-ca-nstab-category'       => 'Vider li págine de categorie',
'tooltip-minoredit'               => 'Marcar to ci quam un redaction minori',
'tooltip-save'                    => 'Conservar tui changes',
'tooltip-preview'                 => 'Monstrar tui changes, pleser usar ante de conservar!',
'tooltip-diff'                    => 'Monstrar quel changes vu executet in li textu',
'tooltip-compareselectedversions' => 'Vider li differenties inter li du revisiones selectet de ti págine',
'tooltip-watch'                   => 'Adjunter ti págine por tui liste de págines vigilat',
'tooltip-recreate'                => 'Recrear li págine por plan anteriori de delete',
'tooltip-upload'                  => 'Comensar cargament de file',
'tooltip-rollback'                => '"Rollback" reverte redaction(es) de ti págine executet per li ultim contributor in un claccar',
'tooltip-undo'                    => '"Undo" reverte ti redaction e inaugura li forme de redaction in modo de prevision. It concede adjuntent un rason in li summarium.',

# Browsing diffs
'previousdiff' => '← Redaction anteriori',
'nextdiff'     => 'Proxim redaction →',

# Media information
'widthheightpage' => '$1×$2, $3 {{PLURAL:$3|págine|págines}}',
'show-big-image'  => 'Resolution complet',

# Special:NewFiles
'newimages' => 'Galerie de nov images',
'ilsubmit'  => 'Serchar',

# Metadata
'metadata'      => 'Metadata',
'metadata-help' => 'Ti file contene information additional, probabilmen adjuntet de li cámera digitale o scandetor usat por crear o digitalizar it. Si li file ha esset redactet de tui statu original, alcun detallies posse ne reflecter completmen li file redactet.',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'omni',
'imagelistall'     => 'omni',
'watchlistall2'    => 'omni',
'namespacesall'    => 'omni',
'monthsall'        => 'omni',

# Trackbacks
'trackbackbox'      => 'Tracies de dorse por ti págine:<br /> $1',
'trackbackexcerpt'  => '; $4 $5: [$2 $1]: <nowiki>$3</nowiki>',
'trackbackremove'   => '([$1 Deleter])',
'trackbacklink'     => 'Tracie de dorse',
'trackbackdeleteok' => 'Li tracie de dorse esset deletet che successe',

# Multipage image navigation
'imgmultigo' => 'Ear!',

# Table pager
'table_pager_limit_submit' => 'Ear',

# Special:Version
'version'       => 'Version',
'version-other' => 'Altri',

# Special:FilePath
'filepath-page' => 'Figura:',

# Special:SpecialPages
'specialpages' => 'Págines special',

);
